==> haskell-text-zipper-0.11-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-zipper
version:              0.11
visibility:           public
id:                   text-zipper-0.11-9zVL5hzNT63Eg1b9D49UNt
key:                  text-zipper-0.11-9zVL5hzNT63Eg1b9D49UNt
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  84c4f016bbd6d818492e2c2625b15e6f
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-8.10.4/site-local/text-zipper-0.11
library-dirs:         /usr/lib/ghc-8.10.4/site-local/text-zipper-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/text-zipper-0.11
hs-libraries:         HStext-zipper-0.11-9zVL5hzNT63Eg1b9D49UNt
depends:
    base-4.14.1.0 deepseq-1.4.4.0 text-1.2.4.1
    vector-0.12.2.0-95IX5pRBJ9d1AshkFlsixP

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.11-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-zipper
version:              0.11
visibility:           public
id:                   text-zipper-0.11-Gy4GzuqR5mqBvmzXGyPsK7
key:                  text-zipper-0.11-Gy4GzuqR5mqBvmzXGyPsK7
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  f55b9dd9145c5c595fb86e489c7dbfb1
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-8.10.4/site-local/text-zipper-0.11
library-dirs:         /usr/lib/ghc-8.10.4/site-local/text-zipper-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/text-zipper-0.11
hs-libraries:         HStext-zipper-0.11-Gy4GzuqR5mqBvmzXGyPsK7
depends:
    base-4.14.1.0 deepseq-1.4.4.0 text-1.2.4.1
    vector-0.12.2.0-7EbNsr7S4xfLPw9HM8zAxH

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
